@@ -2,7 +2,7 @@ var searchData=
 [
   ['harden_0',['harden',['../a00974.html#a95da3cc077feb8d7b244871a8ac7a925',1,'_uno_Environment']]],
   ['has_1',['has',['../a01962.html#a06c455cfa3f0d537503427c53afc2045',1,'com::sun::star::uno::Any']]],
-  ['haselements_2',['hasElements',['../a01010.html#ae0691df9c7c72a5636ffb29db04769c6',1,'com::sun::star::uno::Sequence']]],
+  ['haselements_2',['hasElements',['../a01010.html#ae0691df9c7c72a5636ffb29db04769c6',1,'com::sun::star::uno::Sequence::hasElements()'],['../a01010.html#ae0691df9c7c72a5636ffb29db04769c6',1,'com::sun::star::uno::Sequence&lt; bool &gt;::hasElements()']]],
   ['hashcode_3',['HashCode',['../a00650.html#af2d4eb053e59e20cbceef897c579c5ff',1,'_rtl_Locale']]],
   ['hashcode_4',['hashCode',['../a00666.html#aa2a34f4f40619c75d799b21e5faf863b',1,'rtl::OString::hashCode()'],['../a00754.html#a44b729dfde7f37da377511cbf6d4cbfe',1,'rtl::OUString::hashCode()']]],
   ['hashint32_5fimpl_5',['hashInt32_Impl',['../a01910.html',1,'cppu']]],
